@@ -25,6 +25,7 @@ from __future__ import print_function
 
 import os
 import sys
+import decimal
 
 import compas._os
 
@@ -34,7 +35,7 @@ __copyright__ = 'Copyright 2014-2019 - Block Research Group, ETH Zurich'
 __license__   = 'MIT License'
 __email__     = 'vanmelet@ethz.ch'
 
-__version__ = '0.7.1'
+__version__ = '0.7.2'
 
 
 PY3 = sys.version_info[0] == 3
@@ -59,30 +60,54 @@ __all__ = [
 
 
 def is_windows():
+    """Check if the operating system is Windows.
+
+    Returns
+    -------
+    bool
+        True if the OS is Windows. False otherwise
+
+    """
     return os.name == 'nt'
-
-
 WINDOWS = is_windows()
 
 
 def is_linux():
+    """Check if the operating system is Linux.
+
+    Returns
+    -------
+    bool
+        True if the OS is Linux. False otherwise
+
+    """
     return os.name == 'posix'
-
-
 LINUX = is_linux()
 
 
 def is_mono():
+    """Check if the operating system is running on Mono.
+
+    Returns
+    -------
+    bool
+        True if the OS is running on Mono. False otherwise
+
+    """
     return 'mono' in sys.version.lower()
-
-
 MONO = is_mono()
 
 
 def is_ironpython():
+    """Check if the Python implementation is IronPython.
+
+    Returns
+    -------
+    bool
+        True if the implementation is IronPython. False otherwise
+
+    """
     return 'ironpython' in sys.version.lower()
-
-
 IPY = is_ironpython()
 
 
@@ -106,6 +131,35 @@ def raise_if_ironpython():
         raise
 
 
+def set_precision(precision):
+    """Set the precision used by geometric maps.
+
+    Parameters
+    ----------
+    precision : float
+        The precision as a floating point number.
+        For example, ``0.0001``.
+
+    Notes
+    -----
+    This function converts the floating point number to a string formatting
+    specifier and assigns the specifier to ``compas.PRECISION``.
+
+    Examples
+    --------
+    >>> compas.set_precision(0.001)
+    >>> compas.PRECISION
+    '3f'
+
+    """
+    global PRECISION
+    precision = str(precision)
+    d = decimal.Decimal(precision).as_tuple()
+    if d.exponent < 0:
+        e = abs(d.exponent)
+        PRECISION = "{}f".format(e)
+
+
 # ==============================================================================
 # data
 # ==============================================================================
