@@ -2,22 +2,32 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import compas
+
 from ._mesh import *
 
 from .operations import *
-from .matrices import *
 from .transformations import *
 
+if not compas.IPY:
+    from .matrices import *
+
 from .clean import *
 
 from .combinatorics import *
-from .contours import *
 from .curvature import *
 from .bbox import *
+
+if not compas.IPY:
+    from .contours import *
+
 from .descent import *
 from .duality import *
 from .explode import *
-from .geodesics import *
+
+if not compas.IPY:
+    from .geodesics import *
+
 from .geometry import *
 from .join import *
 from .laplacian import *
