@@ -141,6 +141,7 @@ class Mesh(FromToPickle,
 
     Examples
     --------
+    >>>
 
     """
 
@@ -601,6 +602,49 @@ class Mesh(FromToPickle,
 
         return mesh
 
+    @classmethod
+    def from_polylines(cls, boundary_polylines, other_polylines):
+        """Construct mesh from polylines.
+
+        Based on construction from_lines,
+        with removal of vertices that are not polyline extremities
+        and of faces that represent boundaries.
+
+        This specific method is useful to get the mesh connectivity from a set of (discretised) curves,
+        that could overlap and yield a wrong connectivity if using from_lines based on the polyline extremities only.
+
+        Parameters
+        ----------
+        boundary_polylines : list
+            List of polylines representing boundaries as lists of vertex coordinates.
+        other_polylines : list
+            List of the other polylines as lists of vertex coordinates.
+
+        Returns
+        -------
+        Mesh
+            A mesh object.
+            
+        """
+
+        corner_vertices = [geometric_key(xyz) for polyline in boundary_polylines + other_polylines for xyz in [polyline[0], polyline[-1]]]
+        boundary_vertices = [geometric_key(xyz) for polyline in boundary_polylines for xyz in polyline]
+
+        mesh = cls.from_lines([(u, v) for polyline in boundary_polylines + other_polylines for u, v in pairwise(polyline)])
+
+        # remove the vertices that are not from the polyline extremities and the faces with all their vertices on the boundary
+        vertex_keys = [vkey for vkey in mesh.vertices() if geometric_key(mesh.vertex_coordinates(vkey)) in corner_vertices]
+        vertex_map = {vkey: i for i, vkey in enumerate(vertex_keys)}
+        vertices = [mesh.vertex_coordinates(vkey) for vkey in vertex_keys]
+        faces = []
+        for fkey in mesh.faces():
+            if sum([geometric_key(mesh.vertex_coordinates(vkey)) not in boundary_vertices for vkey in mesh.face_vertices(fkey)]):
+                faces.append([vertex_map[vkey] for vkey in mesh.face_vertices(fkey) if geometric_key(mesh.vertex_coordinates(vkey)) in corner_vertices])
+        
+        mesh.cull_vertices()
+
+        return cls.from_vertices_and_faces(vertices, faces)
+
     @classmethod
     def from_vertices_and_faces(cls, vertices, faces):
         """Construct a mesh object from a list of vertices and faces.
@@ -863,16 +907,23 @@ class Mesh(FromToPickle,
     def _cycle_keys(self, keys):
         return pairwise(keys + keys[0:1])
 
-    def copy(self):
+    def copy(self, cls=None):
         """Make an independent copy of the mesh object.
 
+        Parameters
+        ----------
+        cls : compas.datastructures.Mesh, optional
+            The type of mesh to return.
+            Defaults to the type of the current mesh.
+
         Returns
         -------
         Mesh
             A separate, but identical mesh object.
 
         """
-        cls = type(self)
+        if not cls:
+            cls = type(self)
         return cls.from_data(deepcopy(self.data))
 
     def clear(self):
@@ -1479,7 +1530,7 @@ class Mesh(FromToPickle,
         # each boundary must be taken into account as if it was one face
         B = len(self.boundaries())
 
-        if mesh.is_orientable:
+        if self.is_orientable():
             return (2 - (X + B)) / 2
         else:
             return 2 - (X + B)
