@@ -2,12 +2,12 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-
 from .vector import Vector
 from .point import Point
 from .line import Line
 from .plane import Plane
 from .frame import Frame
+
 from .polyline import Polyline
 from .polygon import Polygon
 from .polyhedron import Polyhedron
@@ -16,6 +16,8 @@ from .curve import Bezier
 from .sphere import Sphere
 
 from .box import Box
-
+from .cylinder import Cylinder
+from .cone import Cone
+from .torus import Torus
 
 __all__ = [name for name in dir() if not name.startswith('_')]
